@@ -24,6 +24,9 @@ class Bmc(object):
     def get_device_id(self):
         return DeviceId(self.send_message_with_name('GetDeviceId'))
 
+    def get_device_guid(self):
+        return DeviceGuid(self.send_message_with_name('GetDeviceGuid'))
+
     def cold_reset(self):
         self.send_message_with_name('ColdReset')
 
@@ -121,6 +124,7 @@ class DeviceId(State):
         string += ' ipmi: %s' % self.ipmi_version
         string += ' manufacturer: %d' % self.manufacturer_id
         string += ' product: %d' % self.product_id
+        string += ' functions: %s' % ','.join(self.supported_functions)
         return string
 
     def supports_function(self, name):
@@ -164,3 +168,14 @@ class DeviceId(State):
         self.aux = None
         if rsp.auxiliary is not None:
             self.aux = list(rsp.auxiliary)
+
+
+class DeviceGuid(State):
+    def __str__(self):
+        return 'Device GUID: %s' % self.device_guid_string
+
+    def _from_response(self, rsp):
+        self.device_guid = rsp.device_guid
+        self.device_guid_string = \
+            '%02x%02x%02x%02x-%02x%02x-%02x%02x-%02x%02x-' \
+            '%02x%02x%02x%02x%02x%02x' % tuple(reversed(self.device_guid))
