@@ -30,3 +30,6 @@ ENTITY_ID_PICMG_MICROTCA_CARRIER_HUB = 0xc2
 ENTITY_ID_PICMG_SHELF_MANAGEMENT_CONTROLLER = 0xf0
 ENTITY_ID_PICMG_FILTRATION_UNIT = 0xf1
 ENTITY_ID_PICMG_SHELF_FRU_INFORMATION = 0xf2
+ENTITY_ID_VITA_FRONT_BOARD = 0xa0
+ENTITY_ID_VITA_REAR_TRANSITION_MODULE = 0xc0
+ENTITY_ID_VITA_XMC = 0xc1
