@@ -22,6 +22,7 @@ import os
 from .errors import DecodingError, CompletionCodeError
 from .msgs import constants
 from .utils import bcd_search, chunks, py3_array_tobytes
+from .fields import FruTypeLengthString
 
 codecs.register(bcd_search)
 
@@ -84,8 +85,80 @@ class Fru(object):
 
         return py3_array_tobytes(data)
 
+    def read_fru_data_full(self, fru_id=0):
+        return self.read_fru_data(fru_id=fru_id)
+
+    def get_fru_inventory_header(self, fru_id=0):
+        data = self.read_fru_data(offset=0, count=8, fru_id=fru_id)
+        return InventoryCommonHeader(data)
+
+    def _read_fru_area(self, offset, fru_id=0):
+        # read the area header
+        data = self.read_fru_data(offset=offset, count=5, fru_id=fru_id)
+        # get the whole area data
+        count = data[1] * 8
+        return self.read_fru_data(offset=offset, count=count, fru_id=fru_id)
+
+    def get_fru_chassis_area(self, fru_id=0):
+        header = self.get_fru_inventory_header(fru_id=fru_id)
+        data = self._read_fru_area(offset=header.chassis_info_area_offset,
+                                   fru_id=fru_id)
+        return InventoryChassisInfoArea(data)
+
+    def get_fru_board_area(self, fru_id=0):
+        header = self.get_fru_inventory_header(fru_id=fru_id)
+        data = self._read_fru_area(offset=header.board_info_area_offset,
+                                   fru_id=fru_id)
+        return InventoryBoardInfoArea(data)
+
+    def get_fru_product_area(self, fru_id=0):
+        header = self.get_fru_inventory_header(fru_id=fru_id)
+        data = self._read_fru_area(offset=header.product_info_area_offset,
+                                   fru_id=fru_id)
+        return InventoryProductInfoArea(data)
+
+    def get_fru_multirecord_area(self, fru_id=0):
+        header = self.get_fru_inventory_header(fru_id=fru_id)
+
+        # we have to determine the length of the area first
+        offset = header.multirecord_area_offset
+        count = 0
+
+        while True:
+            # read the header
+            data = self.read_fru_data(offset=offset, count=5)
+            end_of_list = bool(data[1] & 0x80)
+            length = data[2]
+            count += length + 5
+            offset += length + 5
+            if end_of_list:
+                break
+
+        # now read the full area
+        offset = header.multirecord_area_offset
+        data = self.read_fru_data(offset=offset, count=count)
+        return InventoryMultiRecordArea(data)
+
     def get_fru_inventory(self, fru_id=0):
-        return FruInventory(self.read_fru_data(fru_id=fru_id))
+        """
+        Get the full parsed FRU inventory data.
+        """
+        fru = FruInventory()
+        header = self.get_fru_inventory_header(fru_id=fru_id)
+
+        if header.chassis_info_area_offset:
+            fru.chassis_info_area = self.get_fru_chassis_area(fru_id=fru_id)
+
+        if header.board_info_area_offset:
+            fru.board_info_area = self.get_fru_board_area(fru_id=fru_id)
+
+        if header.product_info_area_offset:
+            fru.product_info_area = self.get_fru_product_area(fru_id=fru_id)
+
+        if header.multirecord_area_offset:
+            fru.multirecord_area = self.get_fru_multirecord_area(fru_id=fru_id)
+
+        return fru
 
 
 def get_fru_inventory_from_file(filename):
@@ -103,38 +176,6 @@ def get_fru_inventory_from_file(filename):
     return FruInventory(data)
 
 
-class FruDataField(object):
-    TYPE_BINARY = 0
-    TYPE_BCD_PLUS = 1
-    TYPE_6BIT_ASCII = 2
-    TYPE_ASCII_OR_UTF16 = 3
-
-    def __init__(self, data=None, offset=0, force_lang_english=False):
-        if data:
-            self._from_data(data, offset, force_lang_english)
-
-    def __str__(self):
-        if self.field_type is FruDataField.TYPE_BINARY:
-            return ' '.join('%02x' % b for b in self.raw)
-        else:
-            return self.value.replace('\x00', '')
-
-    def _from_data(self, data, offset=0, force_lang_english=False):
-        self.offset = offset
-        self.field_type = data[offset] >> 6 & 0x3
-        self.length = data[offset] & 0x3f
-
-        self.raw = data[offset+1:offset+1+self.length]
-
-        chr_data = ''.join([chr(c) for c in self.raw])
-        if self.field_type == self.TYPE_BCD_PLUS:
-            self.value = chr_data.decode('bcd+')
-        elif self.field_type == self.TYPE_6BIT_ASCII:
-            self.value = chr_data.decode('6bitascii')
-        else:
-            self.value = chr_data
-
-
 CUSTOM_FIELD_END = 0xc1
 
 
@@ -142,7 +183,7 @@ def _decode_custom_fields(data):
     offset = 0
     fields = []
     while data[offset] != CUSTOM_FIELD_END:
-        field = FruDataField(data, offset)
+        field = FruTypeLengthString(data, offset)
         fields.append(field)
         offset += field.length + 1
     return fields
@@ -212,9 +253,9 @@ class InventoryChassisInfoArea(CommonInfoArea):
         CommonInfoArea._from_data(self, data)
         self.type = data[2]
         offset = 3
-        self.part_number = FruDataField(data, offset)
+        self.part_number = FruTypeLengthString(data, offset)
         offset += self.part_number.length + 1
-        self.serial_number = FruDataField(data, offset, True)
+        self.serial_number = FruTypeLengthString(data, offset, True)
         offset += self.serial_number.length + 1
         self.custom_chassis_info = _decode_custom_fields(data[offset:])
 
@@ -227,15 +268,15 @@ class InventoryBoardInfoArea(CommonInfoArea):
         self.mfg_date = (datetime.datetime(1996, 1, 1)
                          + datetime.timedelta(minutes=minutes))
         offset = 6
-        self.manufacturer = FruDataField(data, offset)
+        self.manufacturer = FruTypeLengthString(data, offset)
         offset += self.manufacturer.length + 1
-        self.product_name = FruDataField(data, offset)
+        self.product_name = FruTypeLengthString(data, offset)
         offset += self.product_name.length + 1
-        self.serial_number = FruDataField(data, offset, True)
+        self.serial_number = FruTypeLengthString(data, offset, True)
         offset += self.serial_number.length + 1
-        self.part_number = FruDataField(data, offset)
+        self.part_number = FruTypeLengthString(data, offset)
         offset += self.part_number.length + 1
-        self.fru_file_id = FruDataField(data, offset, True)
+        self.fru_file_id = FruTypeLengthString(data, offset, True)
         offset += self.fru_file_id.length + 1
         self.custom_mfg_info = _decode_custom_fields(data[offset:])
 
@@ -245,19 +286,19 @@ class InventoryProductInfoArea(CommonInfoArea):
         CommonInfoArea._from_data(self, data)
         self.language_code = data[2]
         offset = 3
-        self.manufacturer = FruDataField(data, offset)
+        self.manufacturer = FruTypeLengthString(data, offset)
         offset += self.manufacturer.length + 1
-        self.name = FruDataField(data, offset)
+        self.name = FruTypeLengthString(data, offset)
         offset += self.name.length + 1
-        self.part_number = FruDataField(data, offset)
+        self.part_number = FruTypeLengthString(data, offset)
         offset += self.part_number.length + 1
-        self.version = FruDataField(data, offset)
+        self.version = FruTypeLengthString(data, offset)
         offset += self.version.length + 1
-        self.serial_number = FruDataField(data, offset, True)
+        self.serial_number = FruTypeLengthString(data, offset, True)
         offset += self.serial_number.length + 1
-        self.asset_tag = FruDataField(data, offset)
+        self.asset_tag = FruTypeLengthString(data, offset)
         offset += self.asset_tag.length + 1
-        self.fru_file_id = FruDataField(data, offset, True)
+        self.fru_file_id = FruTypeLengthString(data, offset, True)
         offset += self.fru_file_id.length + 1
         self.custom_mfg_info = list()
         self.custom_mfg_info = _decode_custom_fields(data[offset:])
