@@ -15,7 +15,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
 
 from .msgs import create_request_by_name
-from .utils import check_completion_code, ByteBuffer
+from .utils import check_rsp_completion_code, ByteBuffer
 
 LAN_PARAMETER_SET_IN_PROGRESS = 0
 LAN_PARAMETER_AUTHENTICATION_TYPE_SUPPORT = 1
@@ -113,7 +113,14 @@ def data_to_vlan(data):
     """
     Convert a `GetLanConfigurationParameters(LAN_PARAMETER_802_1Q_VLAN_ID)` response
     data into an integer representation of the encoded vlan.
+
+    A disabled VLAN will return a VLAN ID = 0
     """
+    # Check if the vlan is enabled. We return vlan = 0 for a disabled vlan as a
+    # convention.
+    if data[1] >> 7 == 0:
+        return 0
+
     # The vlan ID must be extracted from the response, according to IPMI
     # specification.
     #
@@ -169,7 +176,7 @@ class Lan(object):
             req.set_selector = set_selector
             req.block_selector = block_selector
         rsp = self.send_message(req)
-        check_completion_code(rsp.completion_code)
+        check_rsp_completion_code(rsp)
         return rsp.data
 
     def set_lan_config_param(self, channel,
@@ -179,7 +186,7 @@ class Lan(object):
         req.parameter_selector = parameter_selector
         req.data = data
         rsp = self.send_message(req)
-        check_completion_code(rsp.completion_code)
+        check_rsp_completion_code(rsp)
 
     def get_ip_address(self, channel=0):
         """
