@@ -14,9 +14,6 @@
 # License along with this library; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
 
-from __future__ import absolute_import
-
-
 from . import constants
 from . import register_message_class
 from . import Message
@@ -174,17 +171,19 @@ class GetAcpiPowerStateRsp(Message):
 
 
 @register_message_class
-class GetDeviceGuideReq(Message):
+class GetDeviceGuidReq(Message):
     __cmdid__ = constants.CMDID_GET_DEVICE_GUID
     __netfn__ = constants.NETFN_APP
-    __not_implemented__ = True
 
 
 @register_message_class
-class GetDeviceGuideRsp(Message):
+class GetDeviceGuidRsp(Message):
     __cmdid__ = constants.CMDID_GET_DEVICE_GUID
     __netfn__ = constants.NETFN_APP | 1
-    __not_implemented__ = True
+    __fields__ = (
+        CompletionCode(),
+        ByteArray('device_guid', 16),
+    )
 
 
 @register_message_class
