@@ -14,9 +14,6 @@
 # License along with this library; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
 
-
-from __future__ import absolute_import
-
 from array import array
 
 from . import constants
@@ -73,7 +70,7 @@ class ByteArray(BaseField):
         if self.default is not None:
             return array('B', self.default)
         else:
-            return array('B', self.length * '\x00')
+            return array('B', self.length * b'\x00')
 
 
 class VariableByteArray(ByteArray):
