@@ -94,6 +94,16 @@ SENSOR_TYPE_OEM_KONTRON_SYSTEM_FIRMWARE_UPGRADE = 0xca
 SENSOR_TYPE_OEM_KONTRON_POWER_DENIED = 0xcd
 SENSOR_TYPE_OEM_KONTRON_RESET = 0xcf
 
+# VITA-defined sensor types
+SENSOR_TYPE_VITA_FRU_STATE = 0xf0
+SENSOR_TYPE_VITA_IPMB_LINK = 0xf1
+SENSOR_TYPE_VITA_FRU_HEALTH = 0xf2
+SENSOR_TYPE_VITA_FRU_TEMPERATURE = 0xf3
+SENSOR_TYPE_VITA_PAYLOAD_TEST = 0xf4
+SENSOR_TYPE_VITA_PAYLOAD_TEST_STATUS = 0xf5
+SENSOR_TYPE_VITA_PAYLOAD_MODE = 0xf7
+SENSOR_TYPE_VITA_IPMC_RESET_TYPE = 0xf8
+
 
 class Sensor(object):
     def reserve_device_sdr_repository(self):
