@@ -3,7 +3,7 @@
 
 import pytest
 
-from pyipmi.fields import VersionField
+from pyipmi.fields import (VersionField, FruTypeLengthString)
 from pyipmi.errors import DecodingError
 
 
@@ -26,3 +26,8 @@ def test_versionfield_invalid():
 def test_versionfield_decoding_error():
     with pytest.raises(DecodingError):
         version = VersionField('\x00\x9a')  # noqa:F841
+
+
+def test_FruTypeLengthString_6bitascii():
+    f = FruTypeLengthString(b'\x83d\xc9\xb2\xde', 0)
+    assert f.string == 'DELL'
