@@ -3,7 +3,7 @@
 from pyipmi.ipmitool import parse_interface_options
 
 
-class TestParseInterfaceOptions(object):
+class TestParseInterfaceOptions:
     def test_options_aardvark(self):
         options = parse_interface_options('aardvark', 'serial=1234')
         assert options['serial_number'] == '1234'
@@ -27,8 +27,9 @@ class TestParseInterfaceOptions(object):
         assert options['enable_fastmode'] is False
 
     def test_options_ipmitool(self):
-        options = parse_interface_options('ipmitool', 'interface_type=abcd')
+        options = parse_interface_options('ipmitool', 'interface_type=abcd,cipher=55')
         assert options['interface_type'] == 'abcd'
+        assert options['cipher'] == '55'
 
     def test_options_ipmbdev(self):
         options = parse_interface_options('ipmbdev', 'port=/dev/ipmb0')
